==> flutter_pluggy_connect-0.4.2.tar.gz: lib/src/connect_webview.dart <==
import 'dart:convert';

import 'package:flutter/material.dart';
import 'package:flutter_inappwebview/flutter_inappwebview.dart';

typedef OnLocationUpdateCallback = void Function(String url);
typedef OnOauthOpenCallback = void Function(String oauthUrl);
typedef OnWebViewCreatedCallback = void Function(InAppWebViewController controller);

class ConnectWebView extends StatelessWidget {
  const ConnectWebView(
      {Key? key,
      required this.url,
      required this.onLocationUpdate,
      required this.onOauthOpen,
      required this.onWebViewCreated})
      : super(key: key);

  final String url;
  final OnLocationUpdateCallback onLocationUpdate;
  final OnOauthOpenCallback onOauthOpen;
  final OnWebViewCreatedCallback onWebViewCreated;

  void _onWebViewCreated(InAppWebViewController controller) {
    onWebViewCreated(controller);

    controller.addJavaScriptHandler(
        handlerName: 'pluggyConnectHandler',
        callback: (args) {
          dynamic dataPayload;

          try {
            dataPayload = jsonDecode(args[0] as String);
          } catch (error) {
            return;
          }

          final String type = dataPayload['type'];
          final String message = dataPayload['message'] ?? '';

          if (type == 'OAUTH_OPEN') {
            onOauthOpen(message);
            return;
          }

          if (type == 'LOCATION') {
            // got a location URL update
            onLocationUpdate(message);
            return;
          }
        });
  }

  void _onLoadStart(InAppWebViewController controller, Uri? uri) async {
    /* Note: We are injecting 'ReactNativeWebView' variable because it's implemented
        like this in Connect webapp. We'll keep it like this to simplify API in there. */
    await controller.evaluateJavascript(source: '''
      window.ReactNativeWebView = {
        postMessage: function(message) {
          window.flutter_inappwebview.callHandler("pluggyConnectHandler", message);
        }
      };
      true; // note: this is required, or you'll sometimes get silent failures
    ''');
  }

  @override
  Widget build(BuildContext context) {
    return SafeArea(
        child: InAppWebView(
      initialUrlRequest: URLRequest(url: Uri.parse(url)),
      onWebViewCreated: _onWebViewCreated,
      onLoadStart: _onLoadStart,
    ));
  }
}

==> flutter_pluggy_connect-1.2.0.tar.gz: lib/src/connect_webview.dart <==
import 'dart:convert';

import 'package:flutter/material.dart';
import 'package:flutter_inappwebview/flutter_inappwebview.dart';

typedef OnLocationUpdateCallback = void Function(String url);
typedef OnOauthOpenCallback = void Function(String oauthUrl);
typedef OnWebViewCreatedCallback = void Function(
    InAppWebViewController controller);

class ConnectWebView extends StatelessWidget {
  const ConnectWebView(
      {Key? key,
      required this.url,
      required this.onLocationUpdate,
      required this.onOauthOpen,
      required this.onWebViewCreated})
      : super(key: key);

  final String url;
  final OnLocationUpdateCallback onLocationUpdate;
  final OnOauthOpenCallback onOauthOpen;
  final OnWebViewCreatedCallback onWebViewCreated;

  void _onWebViewCreated(InAppWebViewController controller) {
    onWebViewCreated(controller);

    controller.addJavaScriptHandler(
        handlerName: 'pluggyConnectHandler',
        callback: (args) {
          dynamic dataPayload;

          try {
            dataPayload = jsonDecode(args[0] as String);
          } catch (error) {
            return;
          }

          final String type = dataPayload['type'];
          final String message = dataPayload['message'] ?? '';

          if (type == 'OAUTH_OPEN') {
            onOauthOpen(message);
            return;
          }

          if (type == 'LOCATION') {
            // got a location URL update
            onLocationUpdate(message);
            return;
          }
        });
  }

  void _onLoadStop(InAppWebViewController controller, Uri? uri) async {
    /* Note: We are injecting 'ReactNativeWebView' variable because it's implemented
        like this in Connect webapp. We'll keep it like this to simplify API in there. */
    await controller.evaluateJavascript(source: '''
      window.ReactNativeWebView = {
        postMessage: function(message) {
          window.flutter_inappwebview.callHandler("pluggyConnectHandler", message);
        }
      };
      true; // note: this is required, or you'll sometimes get silent failures
    ''');
  }

  @override
  Widget build(BuildContext context) {
    return SafeArea(
        child: InAppWebView(
      initialUrlRequest: URLRequest(url: Uri.parse(url)),
      onWebViewCreated: _onWebViewCreated,
      onLoadStop: _onLoadStop,
    ));
  }
}
